<?xml version="1.0" encoding="UTF-8"?>

<!--***** ************************************************************* ******-->
<!--*****		    ADMINISTRATIVE INFORMATION			******-->
<!--***** ************************************************************* ******-->

<!--
Contents:
	XSL Stylesheet for displaying data from OLIF file as HTML in Internet
	Explorer 5 in a varying sort order
Dependencies (this file depends on the presence of):

Contact:
        www.olif.net
Status:
	Copyright (C) 2001, OLIF Consortium
Version:
	$DateTime: 2003/11/06 15:47:30 $
	$Revision: #2 $
-->


<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	version="1.0">

<!-- globally accessible parameters with default value -->
<xsl:param name="sortOrder" select="'ascending'"/>
<xsl:param name="sortKey" select="'canForm'"/>

<!--***** ************************************************************* ******-->
<!--*****		    TEMPLATES					******-->
<!--***** ************************************************************* ******-->

<!--***** ************************************************************* ******-->
<!--*****		    template for OLIF root element		******-->
<!--***** ************************************************************* ******-->

<xsl:template match="/">
	<xsl:apply-templates select="//body"/>
</xsl:template>	

<!--***** ************************************************************* ******-->
<!--*****		    template for OLIF body element		******-->
<!--***** ************************************************************* ******-->

<!-- 
0. start a table
1. create a row of table headings with five columns
2. process all 'keyDC' elements in the OLIF data
3. sort the data returned by processing according to the values of the globally
   visible parameters
4. close the table
-->		

<xsl:template match="body">

<table border="1">
	<tr>
		<th>Canonical Form</th>
		<th>Language</th>
		<th>Part-of-Speech</th>
		<th>Subject Field</th>
		<th>Semantic Reading</th>
	</tr>
	<xsl:apply-templates select="entry/mono/keyDC">
	  <!-- attribute value for 'order' has to be escaped by curly braces;
	       other attributes that may be used are 'lang', 'data-type', and
               'case-order' -->
	  <xsl:sort
		select="*[name(.)=$sortKey]"
		order="{$sortOrder}"/>
	</xsl:apply-templates>
</table>

</xsl:template>

<!--***** ************************************************************* ******-->
<!--*****		    template for entry element			******-->
<!--***** ************************************************************* ******-->

<!--
0. start a new table row
1. generate a numeric identifier for the current entry and put it into a table
   cell
2. create more table cells
3. close the table row
-->
	
<xsl:template match="keyDC">

<tr>
  <td><xsl:value-of select="canForm"/></td>
  <td><xsl:value-of select="language"/></td>
  <td><xsl:value-of select="ptOfSpeech"/></td>
  <td><xsl:value-of select="subjField"/></td>
  <td><xsl:value-of select="semReading"/></td>
</tr>
</xsl:template>		

</xsl:stylesheet>

<!--***** ************************************************************* ******-->
<!--*****		    end of XSL					******-->
<!--***** ************************************************************* ******-->
